@@ -22,48 +22,56 @@ file containing all functions for luckybackupwindow
 project version	: Please see "main.cpp" for project version
 
 developer          : luckyb 
-last modified      : 11 Sep 2013
+last modified      : 22 May 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
 
+#include <QTextStream>
+#include <QToolBar>
+
+#include "global.h"
+#include "luckybackupwindow.h"
+#include "operationClass.h"
+#include "textDialog.h"
+
 // InitializeVariables =============================================================================================================================
 // variables initialization
 void luckyBackupWindow::InitializeVariables()
 {    
     TotalOperations = 0;
     currentOperation=-1;
-    NOWexecuting = FALSE;
-    guiModeNormal = TRUE;
-    modifyOK = FALSE;
-    savedProfile = TRUE;
-    taskClicked = FALSE;
-    taskChanged = FALSE;
-    GoBack = FALSE;
+    NOWexecuting = false;
+    guiModeNormal = true;
+    modifyOK = false;
+    savedProfile = true;
+    taskClicked = false;
+    taskChanged = false;
+    GoBack = false;
     InfoData = "";
     InfoInt = 0;
     defaultLanguage = "en";
     mainWindowWidth = 615;
     mainWindowHeight = 500;
-    AreToolbarsLocked = TRUE;
-    IsVisibleProfileComboToolbar = TRUE;
-    IsVisibleProfileToolbar = TRUE;
-    IsVisibleProfileStartToolbar = TRUE;
-    IsVisibleToolbarText = FALSE;
-    IsVisibleInfoWindow = TRUE;
-    validation = FALSE;
+    AreToolbarsLocked = true;
+    IsVisibleProfileComboToolbar = true;
+    IsVisibleProfileToolbar = true;
+    IsVisibleProfileStartToolbar = true;
+    IsVisibleToolbarText = false;
+    IsVisibleInfoWindow = true;
+    validation = false;
     deletedTaskNames.clear();
-    saveOrNot = TRUE;
+    saveOrNot = true;
     manualChapter = "";
-    showOnlyErrors = FALSE;
+    showOnlyErrors = false;
 
     // Running desktop environment
     // kde
     char *isKDE = getenv("KDE_FULL_SESSION");
     if (QString(isKDE) != "")
-        KDErunning = TRUE;
+        KDErunning = true;
     else
-        KDErunning = FALSE;
+        KDErunning = false;
     // if LB is run using kdesu the environmental variable does not work
     // so we will check if kdesud is running as a process...
     // It is commented because the super use cannot use eg the tray notification anyway, so he/she will use the qt stuff
@@ -74,15 +82,15 @@ void luckyBackupWindow::InitializeVariables()
         kdesuProcess -> start ("/bin/sh",kdesuArgs);
         kdesuProcess -> waitForFinished();
         if (kdesuProcess -> exitCode() == 0)        // there is a root process "kdesu_stub running
-            KDErunning = TRUE;
+            KDErunning = true;
     }*/
 
     // gnome
     char *isGnome = getenv("DESKTOP_SESSION");
     if ((QString(isGnome) == "gnome") || (QString(isGnome) == "GNOME"))
-        GNOMErunning = TRUE;
+        GNOMErunning = true;
     else
-        GNOMErunning = TRUE;
+        GNOMErunning = true;
 
     // translations --------------------------------
     TransDir = "";
@@ -266,7 +274,7 @@ void luckyBackupWindow::retranslateUi()
 // Executes when the app starts & when the list of profiles in ~/.luckybackup/profiles changes
 void luckyBackupWindow::createProfileCombo()
 {
-    GoBack = TRUE;	// the next line will execute function setCurrentProfile. set TRUE to avoid that
+    GoBack = true;	// the next line will execute function setCurrentProfile. set true to avoid that
     ui.comboBox_profile -> clear();
     int currentProfileIndex = -1;
     QDir profiledir(profileDir);
@@ -283,15 +291,15 @@ void luckyBackupWindow::createProfileCombo()
 
         profilename.chop(8);
 
-        GoBack = TRUE;	// the next line will execute function setCurrentProfile. set TRUE to avoid that
+        GoBack = true;	// the next line will execute function setCurrentProfile. set true to avoid that
         ui.comboBox_profile -> addItem (profilename);
     }
     if (currentProfileIndex == -1)	// if no default profile exists
         currentProfileIndex = 0;
 
-    GoBack = TRUE;	// the next line will execute function setCurrentProfile. set TRUE to avoid that
+    GoBack = true;	// the next line will execute function setCurrentProfile. set true to avoid that
     ui.comboBox_profile -> setCurrentIndex(currentProfileIndex);
-    GoBack = FALSE;
+    GoBack = false;
 
 }
 
@@ -304,10 +312,10 @@ void luckyBackupWindow::createActions()
     actionAbout = new QAction(QIcon(":/luckyPrefix/about.png"), "About", this);
     
     actionLockToolbars = new QAction("Lock Toolbars",this);
-    actionLockToolbars -> setCheckable(TRUE);
+    actionLockToolbars -> setCheckable(true);
     actionLockToolbars -> setChecked(AreToolbarsLocked);
     actionVisibleToolbarText = new QAction("Labels under icons",this);
-    actionVisibleToolbarText -> setCheckable(TRUE);
+    actionVisibleToolbarText -> setCheckable(true);
     actionVisibleToolbarText -> setChecked(IsVisibleToolbarText);
     
     if (WINrunning)
@@ -458,9 +466,9 @@ bool luckyBackupWindow::checkOperationList()
         }
         
         ui.textBrowser_info -> setText(message);
-        return FALSE;
+        return false;
     }
-    return TRUE;
+    return true;
 }
 
 //checkDeclared ===================================================================================================================================
@@ -469,7 +477,7 @@ bool luckyBackupWindow::checkOperationList()
 void luckyBackupWindow::checkDeclared()
 {
     int currentSelection = ui.listWidget_operations -> currentRow();	//keep the current selection
-    checkDeclaredDirs(TRUE);
+    checkDeclaredDirs(true);
 
     currentOperation = 0;
     CheckedData = "";
@@ -543,7 +551,7 @@ bool luckyBackupWindow::loadCurrentProfile()
         loadData.append("<font color=red><b>" + tr("loading failed","information window message") + "</font></b><br>" +
                 tr("Unable to open profile","information window message. full phrase is 'Unable to open profile <PROFIENAME>'")+" <b>" + profileName + "</b><br><font color=red>"
                 + profile.errorString()) +"</font>";
-        return FALSE;					//do nothing more
+        return false;					//do nothing more
     }
 
     if (loadOK == 2)			// if it is not a valid profile
@@ -551,12 +559,12 @@ bool luckyBackupWindow::loadCurrentProfile()
         loadData.append("<font color=red><b>" + tr("loading failed","information window message") + "</font></b><br>" +
         tr("profile ","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y'. BEWARE of the whitespace in the end")
         + "<b>" + profileName + "</b> " + tr("is not valid for","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + " " + appName +", "+ tr("version:","information window message. Full phrase is: 'profile <PROFILENAME> is not valid for luckybackup version:X.Y") + countStr.setNum(appVersion));
-        return FALSE;	//do nothing more
+        return false;	//do nothing more
     }
 
     // if all went ok (profile loaded) - loadOK == 0
-    savedProfile = TRUE;
-    ui.actionSave -> setEnabled(FALSE);
+    savedProfile = true;
+    ui.actionSave -> setEnabled(false);
     currentOperation = 0;
     while (currentOperation < TotalOperations)	// fill in the task list
     {
@@ -603,7 +611,7 @@ bool luckyBackupWindow::loadCurrentProfile()
     if ( TotalOperations == 0 )
         loadData.append("<br><font color=magenta>" + tr("The task list is empty")+ "<br><b>" + tr("Use the \"add\" button on the right to get started","Please keep the add word inside quotes") + "</b></font><br>");
     
-    return TRUE;	//profile loaded successfuly
+    return true;	//profile loaded successfully
 }
 
 // saveCurrentprofile ===============================================================================================================================
@@ -628,9 +636,9 @@ bool luckyBackupWindow::saveCurrentProfile()
             saveData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'"));
             
         saveData.append(" <b>" + profileName + "</b> "+ tr("could not be saved","Information window message. Full phrase: '(default) profile <PROFILENAME> could not be saved'") + "<br>" +	"<font color=red>"+ profile.errorString() + "</font>");
-        savedProfile = FALSE;
-        ui.actionSave -> setEnabled(TRUE);
-        return FALSE;
+        savedProfile = false;
+        ui.actionSave -> setEnabled(true);
+        return false;
     }
 
     saveData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> saved successfully'") + " <b>" + profileName + "</b> <font color=green>" + tr("saved successfully","Information window message. Full phrase: 'profile <PROFILENAME> saved successfully'") + " !!</font>");
@@ -663,10 +671,10 @@ bool luckyBackupWindow::saveCurrentProfile()
         arrangeLogSnap(0,"delete",deletedTaskNames.at(count));
     deletedTaskNames.clear();
     
-    savedProfile = TRUE;			//change profile status to "saved"
-    ui.actionSave -> setEnabled(FALSE);
+    savedProfile = true;			//change profile status to "saved"
+    ui.actionSave -> setEnabled(false);
     
-    return TRUE;
+    return true;
 }
 
 // createCurrentprofile ===============================================================================================================================
@@ -703,8 +711,8 @@ int luckyBackupWindow::createCurrentProfile()
         createData.append(tr("profile","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " <b>" + profileName + "</b> <font color=green>" + tr("created successfully","Information window message. Full phrase: 'profile <PROFILENAME> created successfully'") + " !!</font>");
         createData.append("<br><font color=magenta>" + tr("Use the \"add\" button on the right to get started","Please keep the add word inside quotes") + "</font><br>");
         createProfileCombo();	// update the profile combobox with all existing profiles
-        savedProfile = TRUE;			//change profile status to "saved"
-        ui.actionSave -> setEnabled(FALSE);
+        savedProfile = true;			//change profile status to "saved"
+        ui.actionSave -> setEnabled(false);
         return 1;		// Profile created successfully
     }
     return 0;	// profile already exists, just proceed
@@ -734,7 +742,7 @@ int luckyBackupWindow::isProfileSaved()
                 if (textdialogQ2.getGoOn() == 0)		//if user answers no
                 {
                     int previousIndex = ui.comboBox_profile -> findText (profileName, Qt::MatchExactly);
-                    GoBack = TRUE;	// the next line will execute  function profileComboChanged again. set TRUE to avoid that
+                    GoBack = true;	// the next line will execute  function profileComboChanged again. set true to avoid that
                     ui.comboBox_profile -> setCurrentIndex(previousIndex);
                     return 0;	//profile could not be saved, user says DO NOT proceed
                 }
@@ -758,7 +766,7 @@ bool luckyBackupWindow::saveSettings()
     if (!settingsfile.open(QIODevice::WriteOnly))	// if the settings file cannot be saved (or fails to create)
     {
         settingsfile.close();
-        return FALSE;
+        return false;
     }
 
     showOnlyErrors = ui.checkBox_onlyShowErrors -> isChecked();
@@ -799,7 +807,7 @@ bool luckyBackupWindow::saveSettings()
     out << "\n[Settings_file_end]" << "\n";	
 
     settingsfile.close();
-    return TRUE;
+    return true;
 }
 
 //loadSettings ===================================================================================================================================
@@ -810,7 +818,7 @@ bool luckyBackupWindow::loadSettings()
     if (!settingsfile.open(QIODevice::ReadOnly))        //if the settings file cannot be opened
     {
         settingsfile.close();
-        return FALSE;
+        return false;
     }
 
     QTextStream in(&settingsfile);
@@ -846,7 +854,7 @@ bool luckyBackupWindow::loadSettings()
     if ( (tempAppName != appName) || (tempAppVersion < validSettingsVersion) || (tempFileType != "luckybackup_settings_file") )
     {
         settingsfile.close();
-        return FALSE;
+        return false;
     }
 
     // Read all lines until the [Settings_file_end] tag or end of file if invalid
@@ -875,7 +883,7 @@ bool luckyBackupWindow::loadSettings()
 
     settingsfile.close();
     ui.checkBox_onlyShowErrors -> setChecked(showOnlyErrors);
-    return TRUE;
+    return true;
 }
 
 //loadSettingsQV ===================================================================================================================================
@@ -886,7 +894,7 @@ bool luckyBackupWindow::loadSettingsQV()
     if (!settingsfile.open(QIODevice::ReadOnly))        //if the settings file cannot be opened
     {
         settingsfile.close();
-        return FALSE;
+        return false;
     }
 
     QDataStream in(&settingsfile);
@@ -908,7 +916,7 @@ bool luckyBackupWindow::loadSettingsQV()
     if ( (tempAppName != appName) || (tempAppVersion < validSettingsVersion) || (tempFileType != "luckybackup_settings_file") )
     {
         settingsfile.close();
-        return FALSE;
+        return false;
     }
 
     in>>v;	vString = v.toString();	in >> v;	//input a label in vString and real data in v
@@ -935,20 +943,20 @@ bool luckyBackupWindow::loadSettingsQV()
     
     saveSettings();     //save the settings file to text format
     
-    return TRUE;
+    return true;
 }
 
 //arrangeLogSnap ===================================================================================================================================
 //Rename-delete-copy logs & snaps when the current profile/task is renamed, deleted,duplicated
 // if a task is deleted, this function is called from saveCurrentProfile()
-// Returns TRUE if everything went ok
+// Returns true if everything went ok
 bool luckyBackupWindow::arrangeLogSnap(bool PorT,QString ActionTaken,QString NameToUse)
 {
     // PorT is "1" for profile and "0" for task
     // ActionTaken can become "rename", "delete" ,"duplicate"
     // NameToUse is the new name of the current profile if rename/duplicate or the file to be deleted or the old name of the task that was renamed/deleted
     
-    bool whatToReturn1 = FALSE, whatToReturn2 = FALSE;
+    bool whatToReturn1 = false, whatToReturn2 = false;
     QStringList filtersSnapLog, snapListFiles, logsListFiles;
     if (PorT)       // we're talking about a profile
         filtersSnapLog << profileName + "-*";       // profileName is the old profile name
@@ -1006,7 +1014,7 @@ bool luckyBackupWindow::arrangeLogSnap(bool PorT,QString ActionTaken,QString Nam
             whatToReturn2 = logfile.copy(logfilename);
     }
     
-    bool whatToReturn = whatToReturn1 && whatToReturn2; // return true if both snaps & log actions finished successfuly
+    bool whatToReturn = whatToReturn1 && whatToReturn2; // return true if both snaps & log actions finished successfully
     return whatToReturn;
 }
 
