@@ -23,14 +23,18 @@
  project version	: Please see "main.cpp" for project version
 
  developer          : luckyb 
- last modified      : 27 Aug 2009
+ last modified      : 22 May 2016
 ===============================================================================================================================
 ===============================================================================================================================
 */
 
 
 #include "logDialog.h"
-#include "readLogFile.cpp"
+
+#include <QTimer>
+
+#include "global.h"
+#include "readLogFile.h"
 
 // class logDialog Constructor=================================================================================================
 
@@ -82,11 +86,11 @@ void logDialog::refreshWindow(const QString &newText)
 void logDialog::logReadEnd()
 {
 	if (totalErrors > 0)
-		uiL.button_next -> setEnabled(TRUE);
+		uiL.button_next -> setEnabled(true);
 	uiL.button_close -> setText(tr("close"));
-	uiL.button_close -> setEnabled(TRUE);
+	uiL.button_close -> setEnabled(true);
 	errorCount = 0;		//set current error to be the first of the logfile
-	firstScroll=TRUE;
+	firstScroll=true;
 }
 
 // refreshWindowError =====================================================================================================
@@ -94,10 +98,10 @@ void logDialog::logReadEnd()
 void logDialog::refreshWindowError(const QString &errorText)
 {
 	uiL.logView -> setText(errorText);
-	uiL.button_next -> setEnabled(FALSE);
-	uiL.button_previous -> setEnabled(FALSE);
+	uiL.button_next -> setEnabled(false);
+	uiL.button_previous -> setEnabled(false);
 	uiL.button_close -> setText(tr("close"));
-	uiL.button_close -> setEnabled(TRUE);
+	uiL.button_close -> setEnabled(true);
 }
 
 // close button pressed=====================================================================================================
@@ -112,10 +116,10 @@ void logDialog::prevError()
 	errorCount--;		//decrease the current error by one
 
 	if (errorCount == 0 )		// if the current error is the first within the logfile disable the previous button
-		uiL.button_previous -> setEnabled(FALSE);
+		uiL.button_previous -> setEnabled(false);
 	
 	if (errorCount < totalErrors-1)	//if the current error is less than the last one within the logfile enable the next button
-		uiL.button_next -> setEnabled(TRUE);
+		uiL.button_next -> setEnabled(true);
 	
 	uiL.logView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));
 }
@@ -125,13 +129,13 @@ void logDialog::nextError()
 {
 	if (!firstScroll)
 		errorCount++;	// increase the current error by one
-	firstScroll = FALSE;
+	firstScroll = false;
 	
 	if (errorCount == totalErrors-1)		// If the current error is the last within the logfile disable the next button
-		uiL.button_next -> setEnabled(FALSE);
+		uiL.button_next -> setEnabled(false);
 	
 	if (errorCount > 0)				// if the current error is greater than the first one within the logfile enable the previous button
-		uiL.button_previous -> setEnabled(TRUE);
+		uiL.button_previous -> setEnabled(true);
 	
 	uiL.logView -> scrollToAnchor("error" + countStr.setNum(errorCount+1));	//scroll to the current error
 }
