@@ -23,7 +23,7 @@ Display a dialog. Schedules profiles via cron
 project version    : Please see "main.cpp" for project version
 
 developer          : luckyb 
-last modified      : 03 Feb 14
+last modified      : 22 May 2016
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -31,24 +31,34 @@ last modified      : 03 Feb 14
 
 
 #include "scheduleDialog.h"
+
+#include <QTextStream>
+#include <QTextCodec>
+#include <QMessageBox>
+#include <QProcess>
+
 #include "scheduleClass.h"
+#include "global.h"
+#include "textDialog.h"
 
 int const maxSchedule = 20;		//The maximum number or profiles schedule permitted
 schedule *Schedule[maxSchedule];	//The array that holds name etc of "schedule list"
-QFile scheduleFile (schedulefilename );
+//QFile scheduleFile (schedulefilename );
 QProcess *cronProcess;		//crontab process
 
 // class scheduleDialog Constructor=================================================================================================
 // schedule existing profiles to execute via cron
-scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
+scheduleDialog::scheduleDialog (QDialog *parent)
+  : QDialog (parent)
+  , scheduleFile(schedulefilename)
 {
     uiS.setupUi(this);
 
     //variables initialization
     TotalSchedule=0;		//The number of available profiles schedulesin "schedule list"- starts from 1
     currentSchedule=0;		//this holds the current row from the "schedule list"- starts from 0
-    noSchedules = TRUE;		//becomes true when no schedules are declared
-    changesMade = FALSE;		//becomes true if changes are made but no cronIt is pressed
+    noSchedules = true;		//becomes true when no schedules are declared
+    changesMade = false;		//becomes true if changes are made but no cronIt is pressed
 
     //connections ----------------------------------------------------------------------------------------------------
     connect(uiS.pushButton_schedule, SIGNAL( pressed() ), this, SLOT(schedulePressed() ) );		//cronIT pushButton
@@ -71,13 +81,13 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
     connect(cronProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(appendCrontabOutput()));
 
     //initialize view of widgets
-    uiS.groupBox_addProfileSchedule -> setVisible(FALSE);
-    uiS.listWidget_schedule -> setEnabled(TRUE);
-    uiS.pushButton_add -> setEnabled(TRUE);
-    uiS.pushButton_modify -> setEnabled(TRUE);
-    uiS.pushButton_remove -> setEnabled(TRUE);
-    uiS.pushButton_cancel -> setEnabled(TRUE);
-    uiS.pushButton_schedule -> setEnabled(TRUE);
+    uiS.groupBox_addProfileSchedule -> setVisible(false);
+    uiS.listWidget_schedule -> setEnabled(true);
+    uiS.pushButton_add -> setEnabled(true);
+    uiS.pushButton_modify -> setEnabled(true);
+    uiS.pushButton_remove -> setEnabled(true);
+    uiS.pushButton_cancel -> setEnabled(true);
+    uiS.pushButton_schedule -> setEnabled(true);
     
     //profile combobox initialization
     uiS.comboBox_profile -> clear();
@@ -262,7 +272,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
         if (TotalSchedule > 0)
         {
             uiS.listWidget_schedule -> setCurrentRow(0);
-            noSchedules = FALSE;
+            noSchedules = false;
         }
         else
             uiS.listWidget_schedule -> addItem(tr("No schedules are declared !!"));
@@ -321,8 +331,8 @@ void scheduleDialog::schedulePressed()
     }
     
     createCron();		//create a cronfile & update user's crontab
-    crontabUpdated = TRUE;
-    changesMade = FALSE;
+    crontabUpdated = true;
+    changesMade = false;
 
     textDialog textdialogI ("QtInformation",  "<font color=blue><b>" + currentUser + "</b></font><br><br>" +
                 tr("Your crontab is updated successfully"), this);
@@ -338,7 +348,7 @@ void scheduleDialog::addPressed()
     if (noSchedules)			// if no schedules are declared, remove the info line first
     {
         uiS.listWidget_schedule -> takeItem (0);
-        noSchedules = FALSE;
+        noSchedules = false;
     }
 
     TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
@@ -352,15 +362,15 @@ void scheduleDialog::addPressed()
         return;
     }
     
-    uiS.groupBox_addProfileSchedule -> setVisible(TRUE);
-    uiS.listWidget_schedule -> setEnabled(FALSE);
+    uiS.groupBox_addProfileSchedule -> setVisible(true);
+    uiS.listWidget_schedule -> setEnabled(false);
     uiS.groupBox_addProfileSchedule -> setTitle(tr("Add profile schedule"));
-    uiS.pushButton_add -> setEnabled(FALSE);
-    uiS.pushButton_modify -> setEnabled(FALSE);
-    uiS.pushButton_remove -> setEnabled(FALSE);
-    uiS.pushButton_cancel -> setEnabled(FALSE);
-    uiS.pushButton_schedule -> setEnabled(FALSE);
-    uiS.pushButton_viewCrontab -> setEnabled(FALSE);
+    uiS.pushButton_add -> setEnabled(false);
+    uiS.pushButton_modify -> setEnabled(false);
+    uiS.pushButton_remove -> setEnabled(false);
+    uiS.pushButton_cancel -> setEnabled(false);
+    uiS.pushButton_schedule -> setEnabled(false);
+    uiS.pushButton_viewCrontab -> setEnabled(false);
     clearScheduleDetails();
 }
 
@@ -372,15 +382,15 @@ void scheduleDialog::modifyPressed()
     if ((currentSchedule < 0) || (noSchedules))				//if nothing is selected or no schedules declared, do nothing
         return;
 
-    uiS.groupBox_addProfileSchedule -> setVisible(TRUE);
+    uiS.groupBox_addProfileSchedule -> setVisible(true);
     uiS.groupBox_addProfileSchedule -> setTitle(tr("Modify profile schedule"));
-    uiS.listWidget_schedule -> setEnabled(FALSE);
-    uiS.pushButton_add -> setEnabled(FALSE);
-    uiS.pushButton_modify -> setEnabled(FALSE);
-    uiS.pushButton_remove -> setEnabled(FALSE);
-    uiS.pushButton_cancel -> setEnabled(FALSE);
-    uiS.pushButton_schedule -> setEnabled(FALSE);
-    uiS.pushButton_viewCrontab -> setEnabled(FALSE);
+    uiS.listWidget_schedule -> setEnabled(false);
+    uiS.pushButton_add -> setEnabled(false);
+    uiS.pushButton_modify -> setEnabled(false);
+    uiS.pushButton_remove -> setEnabled(false);
+    uiS.pushButton_cancel -> setEnabled(false);
+    uiS.pushButton_schedule -> setEnabled(false);
+    uiS.pushButton_viewCrontab -> setEnabled(false);
 }
 
 
@@ -403,10 +413,10 @@ void scheduleDialog::removePressed()
     TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
     if (TotalSchedule == 0)
     {
-        noSchedules = TRUE;
+        noSchedules = true;
         uiS.listWidget_schedule -> addItem(tr("No schedules are declared !!"));
     }
-    changesMade = TRUE;    
+    changesMade = true;    
 }
 
 // current button pressed==============================================================================================
@@ -436,19 +446,19 @@ void scheduleDialog::viewCrontab()
 void scheduleDialog::modifyCancelPressed()
 {
     uiS.groupBox_addProfileSchedule -> setTitle(tr("Profile schedule details"));
-    uiS.groupBox_addProfileSchedule -> setVisible(FALSE);
-    uiS.listWidget_schedule -> setEnabled(TRUE);
-    uiS.pushButton_add -> setEnabled(TRUE);
-    uiS.pushButton_modify -> setEnabled(TRUE);
-    uiS.pushButton_remove -> setEnabled(TRUE);
-    uiS.pushButton_cancel -> setEnabled(TRUE);
-    uiS.pushButton_schedule -> setEnabled(TRUE);
-    uiS.pushButton_viewCrontab -> setEnabled(TRUE);
+    uiS.groupBox_addProfileSchedule -> setVisible(false);
+    uiS.listWidget_schedule -> setEnabled(true);
+    uiS.pushButton_add -> setEnabled(true);
+    uiS.pushButton_modify -> setEnabled(true);
+    uiS.pushButton_remove -> setEnabled(true);
+    uiS.pushButton_cancel -> setEnabled(true);
+    uiS.pushButton_schedule -> setEnabled(true);
+    uiS.pushButton_viewCrontab -> setEnabled(true);
 
     TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
     if (TotalSchedule == 0)
     {
-        noSchedules = TRUE;
+        noSchedules = true;
         uiS.listWidget_schedule -> addItem(tr("No schedules are declared !!"));
     }
 }
@@ -506,7 +516,7 @@ void scheduleDialog::fillDetails()
 // adss a new profile scedule to the list or modifies an existing one
 void scheduleDialog::okaySchedulePressed()
 {
-    noSchedules = FALSE;
+    noSchedules = false;
     schedule *tempOp = new schedule;
 
     //check valid & existent profile*****************************************************
@@ -573,7 +583,7 @@ void scheduleDialog::okaySchedulePressed()
     TotalSchedule = uiS.listWidget_schedule -> count();		//set the TotalSchedule to what it is now
 
     modifyCancelPressed();
-    changesMade = TRUE;
+    changesMade = true;
 }
 
 // scheduleText=====================================================================================================
@@ -891,7 +901,7 @@ bool scheduleDialog::saveScheduleFile()
         scheduleFile.remove();
 
     if (!scheduleFile.open(QIODevice::WriteOnly))   //create a new schedule file
-        return FALSE;
+        return false;
     else        //write some stuff to schedule file
     {
         QTextStream out(&scheduleFile);
@@ -936,7 +946,7 @@ bool scheduleDialog::saveScheduleFile()
     }
     
     scheduleFile.close();   //close the file
-    return TRUE;
+    return true;
 }
 
 // end of scheduleDialog.cpp ---------------------------------------------------------------------------
